#ifndef NT2_CORE_INCLUDE_FUNCTIONS_GLOBALFIND_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_GLOBALFIND_HPP_INCLUDED

#include <nt2/core/functions/globalfind.hpp>
#include <nt2/core/functions/expr/globalfind.hpp>

#endif
